@@ -214,6 +214,9 @@ class _SSLSocketWrapper(object):
     def close(self):
         self._ssl.close()
 
+    def fileno(self):
+        return self._ssl.fileno()
+
 _BOOL_VALUES = (0, 1)
 
 
@@ -374,6 +377,9 @@ class WebSocket(object):
             self.sock.setsockopt(*opts)
         self.get_mask_key = get_mask_key
 
+    def fileno(self):
+        return self.sock.fileno()
+
     def set_mask_key(self, func):
         """
         set function to create musk key. You can custumize mask key generator.
@@ -442,7 +448,7 @@ class WebSocket(object):
         if "origin" in options:
             headers.append("Origin: %s" % options["origin"])
         else:
-            headers.append("Origin: %s" % hostport)
+            headers.append("Origin: http://%s" % hostport)
 
         key = _create_sec_websocket_key()
         headers.append("Sec-WebSocket-Key: %s" % key)
@@ -659,8 +665,10 @@ class WebSocket(object):
                 self.sock.settimeout(3)
                 try:
                     frame = self.recv_frame()
-                    if logger.isEnabledFor(logging.DEBUG):
-                        logger.error("close status: " + repr(frame.data))
+                    if logger.isEnabledFor(logging.ERROR):
+                        recv_status = struct.unpack("!H", frame.data)[0]
+                        if recv_status != STATUS_NORMAL:
+                            logger.error("close status: " + repr(recv_status))
                 except:
                     pass
                 self.sock.settimeout(timeout)
